/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2006 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Sam Lantinga
    slouken@libsdl.org
*/
#include "SDL_config.h"

#include "../../events/SDL_sysevents.h"
#include "../../events/SDL_events_c.h"
#include <wiiuse/wpad.h>

#include "SDL_gamecubevideo.h"
#include "SDL_gamecubeevents_c.h"

int lastX = 0;
int lastY = 0;
Uint8 lastButtonStateA = SDL_RELEASED;
Uint8 lastButtonStateB = SDL_RELEASED;
Uint8 lastButtonStateHome = SDL_RELEASED;

void GAMECUBE_PumpEvents(_THIS)
{
	WPAD_ScanPads();
	WPADData *wd = WPAD_Data(0);

	if(wd->ir.valid)
	{
		int x = wd->ir.x;
		int y = wd->ir.y;

		if(lastX != x || lastY != y)
		{
			SDL_PrivateMouseMotion(0, 0, x, y);
			lastX = x;
			lastY = y;
		}
		
		Uint8 stateA = SDL_RELEASED;
		Uint8 stateB = SDL_RELEASED;
		if(wd->btns_h & WPAD_BUTTON_A)
		{
			stateA = SDL_PRESSED;
		}
		if(wd->btns_h & WPAD_BUTTON_B)
		{
			stateB = SDL_PRESSED;
		}
		
		if(stateA != lastButtonStateA)
		{
			lastButtonStateA = stateA;
			SDL_PrivateMouseButton(stateA, SDL_BUTTON_LEFT, x, y);
		}
		if(stateB != lastButtonStateB)
		{
			lastButtonStateB = stateB;
			SDL_PrivateMouseButton(stateB, SDL_BUTTON_RIGHT, x, y);
		}
	}

	Uint8 stateHome = SDL_RELEASED;
	if(wd->btns_h & WPAD_BUTTON_HOME)
	{
		stateHome = SDL_PRESSED;
	}
	if(stateHome != lastButtonStateHome)
	{
		lastButtonStateHome = stateHome;
		SDL_keysym keysym;
		SDL_memset(&keysym, 0, (sizeof keysym));
		keysym.sym = SDLK_ESCAPE;
		SDL_PrivateKeyboard(stateHome, &keysym);
	}
}

void GAMECUBE_InitOSKeymap(_THIS)
{
	/* do nothing. */
}

/* end of SDL_nullevents.c ... */

